@@ -2,7 +2,7 @@ package HTTP::MobileAgent::AirHPhone;
 
 use strict;
 use vars qw($VERSION);
-$VERSION = 0.19;
+$VERSION = 0.09;
 
 use base qw(HTTP::MobileAgent);
 
@@ -12,10 +12,6 @@ __PACKAGE__->make_accessors(
 
 sub is_airh_phone { 1 }
 
-sub carrier { 'H' }
-
-sub carrier_longname { 'AirH' }
-
 sub name { 'DDIPOCKET' }
 
 sub parse {
@@ -26,11 +22,6 @@ sub parse {
     $self->{cache_size} =~ s/^c//;
 }
 
-sub _make_display {
-    # XXX
-}
-
-
 1;
 __END__
 
